@@ -75,16 +75,6 @@ class Action(BaseAction):
                 name=self.name
             )
 
-    def validate(self):
-        """
-        Validate routes for current API scope.
-        """
-        if self.route and self.api_level:
-            spec_path = os.path.join(defaults.CONFIG_DIRECTORY,
-                                     '{}.json'.format(self.api_level))
-            api_routes = json.load(open(spec_path, 'r'))['paths'].keys()
-            assert api_routes and self.route in api_routes, self.name
-
     def _check_arguments(self, **kwargs):
         route_data = self.raw_spec['paths'][self.route]
         if 'parameters' not in route_data:
@@ -372,9 +362,21 @@ class Action(BaseAction):
     def _list_concrete_types(self, schema):
         types = []
         if "x-concreteTypes" in schema:
-            types = [ref_dict['$ref'].split("/")[-1] for ref_dict in schema["x-concreteTypes"]]
+            for ref_dict in schema["x-concreteTypes"]:
+                ref_link = ref_dict['$ref']
+                types += [link.split("/")[-1] for link in self._list_concrete_types_recursive(ref_link)]
         return types
 
+    def _list_concrete_types_recursive(self, reference):
+        references = []
+        schema = self._lookup(reference)
+        if "x-concreteTypes" not in schema:
+            references.append(reference)
+        else:
+            for ref_dict in schema["x-concreteTypes"]:
+                references += self._list_concrete_types_recursive(ref_dict['$ref'])
+        return references
+
     def _filter_json_object(self, data, filter_createonly=False,
                             schema=None, reference=None):
         """
@@ -534,6 +536,9 @@ class Action(BaseAction):
         if '{envId}' in uri and not kwargs.get('envId') and settings.envId:
             kwargs['envId'] = settings.envId
 
+        if '{accountId}' in uri and not kwargs.get('accountId') and settings.accountId:
+            kwargs['accountId'] = settings.accountId
+
         if kwargs:
             # filtering in-body and empty params
             uri = self._request_template.format(**kwargs)
@@ -578,7 +583,8 @@ class Action(BaseAction):
         for option in options:
             if self.prompt_for and option.name in self.prompt_for:
                 option.prompt = option.name
-            if option.name == 'envId' and settings.envId:
+            if (option.name == 'envId' and settings.envId) or \
+                    (option.name == 'accountId' and settings.accountId):
                 option.required = False
         return options
 
@@ -597,4 +603,10 @@ class Action(BaseAction):
             spec_path = os.path.join(defaults.CONFIG_DIRECTORY,
                                      '{}.json'.format(self.api_level))
             api_routes = json.load(open(spec_path, 'r'))['paths'].keys()
-            assert api_routes and self.route in api_routes, self.name
+            try:
+                assert api_routes and self.route in api_routes, self.name
+            except AssertionError:  # ST-224
+                if self.api_level == "account":
+                    bc_route = self.route.replace('{accountId}/', '')
+                    assert api_routes and bc_route in api_routes, self.name
+                    self.route = bc_route
